@@ -381,10 +381,14 @@ class TLS(PlugIn):
         return self._tcpsock._seen_data or select.select([self._tcpsock._sslObj],[],[],timeout)[0]
 
     def _startSSL(self):
-        """ Immidiatedly switch socket to TLS mode. Used internally."""
+        """ Immediately switch socket to TLS mode. Used internally."""
         """ Here we should switch pending_data to hint mode."""
         tcpsock=self._owner.Connection
-        context=ssl.SSLContext(ssl.PROTOCOL_TLS_CLIENT)
+        if sys.version_info >= (3, 0, 0):
+            protocol = ssl.PROTOCOL_TLS_CLIENT
+        else:
+            protocol = ssl.PROTOCOL_TLS
+        context=ssl.SSLContext(protocol)
         context.check_hostname = False
         context.verify_mode = ssl.CERT_NONE
 
@@ -453,7 +457,7 @@ class Bosh(PlugIn):
         self.use_srv = use_srv
         self.Sid = None
         self._rid = 0
-        self.wait = 80
+        self.wait = wait
         self.hold = hold
         self.requests = requests
         self._pipeline = None
@@ -538,6 +542,8 @@ class Bosh(PlugIn):
 
     def receive(self):
         resp = ''
+        if len(self._respobjs) == 0:
+            return resp
         if self.PIPELINE:
             res, data = self._respobjs.pop(0)
         else:
@@ -589,7 +595,7 @@ class Bosh(PlugIn):
             self.DEBUG("Invalid/Corrupt Stream", 'error')
             raise Exception("Disconnected from server")
         else:
-            msg = "Recieved status not defined in XEP-1204: %s" % res.status
+            msg = "Recieved status not defined in XEP-0124: %s" % res.status
             self.DEBUG(msg, 'error')
             raise Exception("Disconnected from server")
         node = Node(node=data)
@@ -671,7 +677,8 @@ class Bosh(PlugIn):
                         route = '%s:%s' % self._server, self._port
                     else:
                         route = self._server
-                    body.setAttr('route', route)
+                    if route:
+                        body.setAttr('route', route)
         else:
             # Mid stream, wrap the xml stanza in a BOSH body wrapper
             if stream:
